<?php
/**
 * @file
 * Wraps your content with a div with bootstrap column size classes.
 */

namespace Drupal\shortcode_asciinema\Plugin\Shortcode;

use Drupal\Core\Language\Language;
use Drupal\shortcode\Plugin\ShortcodeBase;

/**
 * Provides a shortcode for asciinema videos.
 *
 * @Shortcode(
 *   id = "asciinema",
 *   title = @Translation("Asciinema video"),
 *   description = @Translation("Embeds an asciinema video")
 * )
 */
class AsciinemaShortcode extends ShortcodeBase {

  public function process($attributes, $id, $langcode = Language::LANGCODE_NOT_SPECIFIED) {
    $attributes = $this->getAttributes(array(
      'autoplay' => '1',
      'loop' => '1',
      'preload' => '1',
      'size' => 'big',
      'speed' => '1',
      't' => 0,
      'theme' => 'asciinema',
    ),
      $attributes
    );

    $attributes_string = '';
    foreach ($attributes as $key => $value) {
      $attributes_string .= " data-$key=\"$value\"";
    }

    $src = "https://asciinema.org/a/$id.js";

    return "<script type=\"text/javascript\" src=\"$src\" id=\"asciicast-$id\" $attributes_string async></script>";
  }

  /**
   * {@inheritdoc}
   */
  public function tips($long = FALSE) {
    $output = array();
    $output[] = '<p><strong>' . $this->t('[asciinema size="big" autoplay="1" loop="1" theme="asciinema" speed="1" t="0"]105302[/asciinema]') . '</strong> ';
    if ($long) {
      $output[] = $this->t('Generates an asciinema.org <script> tag. All attributes are optional. You must insert the video ID as the tag value. E.g., 105302.') . '</p>';
    }
    else {
      $output[] = $this->t('Generates an asciinema.org <script> tag.') . '</p>';
    }

    return implode(' ', $output);
  }
}
